package cz.moneta.test.regression.commercial.auto.smartauto.mockdata;

import cz.moneta.test.dsl.auto.smartauto.shared.*;

public class SharedMock {

    // CONTACT
    public static CompanyData prepareCompanyData() {
        CompanyData companyData = new CompanyData();
        return companyData.setCompany(Company.AVAST)
                .setCompanyContactAddress(Address.BRANICKA)
                .setCompanyPhoneNumber("721456789")
                .setCompanyOtherPhoneNumber("721852963")
                .setCompanyEmail("test@test.cz")
                .setIco(Ico.AVAST)
                .setCompanyCountry(Nationality.CZECH_REPUBLIC);
    }

    public static ContactData prepareContactDataWoman() {
        ContactData contactData = new ContactData();
        return contactData.setName("Jana")
                .setSurname("Překrásná")
                .setTitleBefore("Ing.")
                .setTitleAfter("Ph.D.")
                .setPhoneNumber("721456789")
                .setOtherPhoneNumber("721741852")
                .setEmail("jana@prekrasna.cz")
                .setAddress(Address.BRANICKA)
                .setContactAddress(Address.BRANICKA);
    }

    public static IdentificationData prepareIdentificationDataWoman() {
        IdentificationData identificationData = new IdentificationData();
        return identificationData.setNationality(Nationality.CZECH_REPUBLIC)
                .setCountry(Country.CZECH_REPUBLIC)
                .setPin(Pin.DEFAULT_PIN_WOMAN)
                .setBirthdate(Birthdate.DEFAULT_BIRTHDATE_WOMAN)
                .setBirthplace("Praha")
                .setIdentificationType(IdentificationType.IDENTITY_CARD)
                .setIdentificationIdNumber("200115551")
                .setIdentificationIdValidity("28.01.2029")
                .setCompanyRole(CompanyRole.SECRETARY)
                .setStayType(StayType.PERMANENT);

    }

    public static ContactData prepareContactDataMan() {
        ContactData contactData = new ContactData();
        return contactData.setName("Karel")
                .setSurname("Nový")
                .setTitleBefore("Ing.")
                .setTitleAfter("Ph.D.")
                .setPhoneNumber("721456789")
                .setOtherPhoneNumber("721741852")
                .setEmail("karel@novy.cz")
                .setAddress(Address.BRANICKA)
                .setContactAddress(Address.BRANICKA);
    }

    public static IdentificationData prepareIdentificationDataMan() {
        IdentificationData identificationData = new IdentificationData();
        return identificationData.setNationality(Nationality.CZECH_REPUBLIC)
                .setCountry(Country.CZECH_REPUBLIC)
                .setPin(Pin.DEFAULT_PIN_MAN)
                .setBirthdate(Birthdate.DEFAULT_BIRTHDATE_MAN)
                .setBirthplace("Praha")
                .setIdentificationType(IdentificationType.IDENTITY_CARD)
                .setIdentificationIdNumber("200115551")
                .setIdentificationIdValidity("28.01.2029")
                .setCompanyRole(CompanyRole.SECRETARY)
                .setStayType(StayType.PERMANENT);
    }

    // DATE
    public static DateData prepareDateDataFrom() {
        return new DateData(Year._2023, new Month(4), new Day(13));
    }

    public static DateData prepareDateDataTo() {
        return new DateData(Year._2024, new Month(4), new Day(13));
    }
}
